"""
Tests for the Workflow Monitor Reacquisition system
"""
from pathlib import Path
from unittest.mock import MagicMock, patch, mock_open

from pendulum import DateTime
from testing.utils.conftest import mock_workflow_requests

import workspaces.workflow.services.recovery as recovery

fake_profile = "test-dev"


@patch("pathlib.Path.exists", MagicMock(return_value=True))
def test_ensure_initial_setup_false():
    assert recovery._ensure_initial_startup() is False


@patch("pathlib.Path.exists", MagicMock(return_value=False))
@patch("pendulum.now", MagicMock(return_value=DateTime(2022, 3, 30, 22, 22, 17)))
def test_ensure_initial_setup_true():
    with patch("builtins.open", mock_open()) as o:
        recovery._ensure_initial_startup()
        o.assert_called_with("reacquire.txt", "w")
        handle = o()
        content = "The Workflow Reacquire system was started within this container at 2022-03-30T22:22:17\n"
        handle.write.assert_called_with(content)
        handle.close.assert_called_once()


@patch.dict("os.environ", {"CAPO_PROFILE": fake_profile})
def test_get_environment():
    assert recovery.get_environment() == "dev"


class TestMonitorRecover:
    # def test_on_restart(self):
    #     pass

    def test_reacquire_logfile_empty_path(self, mock_workflow_requests):
        assert recovery.MonitorRecover._reacquire_logfile(mock_workflow_requests[0]) == Path(".")

    # def test_reacquire_logfile_path(self):
    #     pass

    # @patch("subprocess.Popen")
    # def test_restart_monitor(self, mock_subprocess):
    #     pass
    #
    # def test_reacquire_inflight_requests(self):
    #     pass
